TripletSample class
Bundle of three patchified images used by triplet-loss metric learning (anchor + positive from the same class, negative from a different class).
Constructors
Properties
- anchor → Tensor
-
final
- anchorClass → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- negative → Tensor
-
final
- negativeClass → int
-
final
- positive → Tensor
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited