LmSample class

One (input, target) pair for next-token prediction training.

Constructors

LmSample(Tensor input, Tensor target)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
input Tensor
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target Tensor
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited