BertConfig class

Constructors

BertConfig({required int vocabSize, required int maxPositionEmbeddings, required int embedDim, required int numLayers, required int numHeads, required int intermediateSize, double layerNormEps = 1e-12, int typeVocabSize = 2, Device device = Device.CPU, int seed = 0})
const

Properties

device Device
final
embedDim int
final
hashCode int
The hash code for this object.
no setterinherited
intermediateSize int
final
layerNormEps double
final
maxPositionEmbeddings int
final
numHeads int
final
numLayers int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed int
final
typeVocabSize int
final
vocabSize int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited