BertHFLoader class

Constructors

BertHFLoader()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

bertBaseUncasedConfig({Device device = Device.CPU, int seed = 0}) BertConfig
bert-base-uncased: 12 layers, hidden=768, heads=12, ffn=3072.
loadFile(BertModel model, String path, {bool keepFp16 = false}) BertLoadReport
loadMap(BertModel model, Map<String, Tensor> state) BertLoadReport
miniLmL6V2Config({Device device = Device.CPU, int seed = 0}) BertConfig
all-MiniLM-L6-v2 (nreimers/MiniLM-L6-H384-uncased backbone): 6 layers, hidden=384, heads=12, ffn=1536, vocab=30522.