Lc0Input class

Constructors

Lc0Input()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromFen(String fen) Tensor
Parse a FEN into a [1, 112, 8, 8] CPU tensor ready to feed into Lc0Net.