PythiaConfig class

Constructors

PythiaConfig({required int vocabSize, required int maxCtx, required int embedDim, required int numLayers, required int numHeads, int? ffnDim, double ropeBase = 10000.0, double rotaryPct = 0.25, Device device = Device.CPU, int seed = 0})

Properties

device Device
final
embedDim int
final
ffnDim int
final
hashCode int
The hash code for this object.
no setterinherited
maxCtx int
final
numHeads int
final
numLayers int
final
ropeBase double
final
rotaryPct double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed int
final
vocabSize int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited