CsvDataset class
Constructors
-
CsvDataset.fromFile(String path, {int? labelColumn, Map<
String, int> ? classMap, bool hasHeader = true, String delimiter = ',', Device device = Device.CPU}) -
factory
-
CsvDataset.fromLines(List<
String> lines, {int? labelColumn, Map<String, int> ? classMap, bool hasHeader = true, String delimiter = ',', Device device = Device.CPU}) -
factory
Properties
- device → Device
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ List<
String> -
final
- length → int
-
no setteroverride
- numExamples → int
-
no setter
- numFeatures → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int index) → CsvSample -
override