TextEncoder class abstract
The interface TextTokenDataset needs from a tokenizer. Both
CharTokenizer and BpeTokenizer satisfy this via structural
typing (Dart uses subtyping, so we accept anything with an
encode method matching this shape).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
String s) → List< int> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited