EncoderCache class
Constructors
-
EncoderCache(List<MHACache> layers)
-
-
EncoderCache.empty(int numLayers, int numKvHeads)
-
Fresh cache sized for a stack of
numLayers blocks each with
numKvHeads KV-head slots (equal to the Q-head count for
standard MHA; smaller for GQA).
factory
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
layers
→ List<MHACache>
-
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
seqLen
→ int
-
Length of the sequence cached so far. Reads from layer 0.
no setter
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited